pub trait ClaimAssets {
// Required method
fn claim_assets(
origin: &Location,
ticket: &Location,
what: &Assets,
context: &XcmContext,
) -> Option<AssetsInHolding>;
}Expand description
Define any handlers for the AssetClaim instruction.
Types implementing this trait should make sure to properly handle imbalances held within the
trap and pass them over to AssetsInHolding. Generally should have a mirror DropAssets
implementation that originally moved the imbalance from holding to this trap.
Required Methods
Sourcefn claim_assets(
origin: &Location,
ticket: &Location,
what: &Assets,
context: &XcmContext,
) -> Option<AssetsInHolding>
fn claim_assets( origin: &Location, ticket: &Location, what: &Assets, context: &XcmContext, ) -> Option<AssetsInHolding>
Claim any assets available to origin and return them in a single AssetsInHolding value,
together with the weight used by this operation.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.