referrerpolicy=no-referrer-when-downgrade

DropAssets

Trait DropAssets 

pub trait DropAssets {
    // Required method
    fn drop_assets(
        origin: &Location,
        assets: AssetsInHolding,
        context: &XcmContext,
    ) -> Weight;
}
Define a handler for when some non-empty AssetsInHolding value should be dropped.

Types implementing this trait should make sure to properly handle imbalances held within AssetsInHolding. Generally should have a mirror ClaimAssets implementation that can recover the imbalance back into holding.

Required Methods

fn drop_assets( origin: &Location, assets: AssetsInHolding, context: &XcmContext, ) -> Weight

Handler for receiving dropped assets. Returns the weight consumed by this operation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl DropAssets for ()

Source

fn drop_assets( _origin: &Location, _assets: AssetsInHolding, _context: &XcmContext, ) -> Weight

Implementors